@@ -16,8 +16,8 @@
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import grpc_helpers  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
+from google.api_core import grpc_helpers
+from google.api_core import gapic_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
@@ -159,8 +159,11 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
         if not self._grpc_channel:
             self._grpc_channel = type(self).create_channel(
                 self._host,
+                # use the credentials which are saved
                 credentials=self._credentials,
-                credentials_file=credentials_file,
+                # Set ``credentials_file`` to ``None`` here as
+                # the credentials that we saved earlier should be used.
+                credentials_file=None,
                 scopes=self._scopes,
                 ssl_credentials=self._ssl_channel_credentials,
                 quota_project_id=quota_project_id,
@@ -1019,7 +1022,10 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
     ) -> Callable[[cluster_service.SetNodePoolSizeRequest], cluster_service.Operation]:
         r"""Return a callable for the set node pool size method over gRPC.
 
-        Sets the size for a specific node pool.
+        Sets the size for a specific node pool. The new size will be
+        used for all replicas, including future replicas created by
+        modifying
+        [NodePool.locations][google.container.v1.NodePool.locations].
 
         Returns:
             Callable[[~.SetNodePoolSizeRequest],
