@@ -16,7 +16,9 @@
 from .cluster_service import (
     AcceleratorConfig,
     AddonsConfig,
+    AdvancedMachineFeatures,
     AuthenticatorGroupsConfig,
+    Autopilot,
     AutoprovisioningNodePoolDefaults,
     AutoUpgradeOptions,
     BinaryAuthorization,
@@ -27,6 +29,7 @@ from .cluster_service import (
     ClusterAutoscaling,
     ClusterUpdate,
     CompleteIPRotationRequest,
+    ConfidentialNodes,
     ConfigConnectorConfig,
     CreateClusterRequest,
     CreateNodePoolRequest,
@@ -36,6 +39,10 @@ from .cluster_service import (
     DeleteClusterRequest,
     DeleteNodePoolRequest,
     DnsCacheConfig,
+    DNSConfig,
+    GcePersistentDiskCsiDriverConfig,
+    GcfsConfig,
+    GcpFilestoreCsiDriverConfig,
     GetClusterRequest,
     GetJSONWebKeysRequest,
     GetJSONWebKeysResponse,
@@ -46,11 +53,13 @@ from .cluster_service import (
     GetServerConfigRequest,
     HorizontalPodAutoscaling,
     HttpLoadBalancing,
+    ILBSubsettingConfig,
     IntraNodeVisibilityConfig,
     IPAllocationPolicy,
     Jwk,
     KubernetesDashboard,
     LegacyAbac,
+    LinuxNodeConfig,
     ListClustersRequest,
     ListClustersResponse,
     ListNodePoolsRequest,
@@ -59,19 +68,30 @@ from .cluster_service import (
     ListOperationsResponse,
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
+    LoggingComponentConfig,
+    LoggingConfig,
+    MaintenanceExclusionOptions,
     MaintenancePolicy,
     MaintenanceWindow,
     MasterAuth,
     MasterAuthorizedNetworksConfig,
     MaxPodsConstraint,
+    MeshCertificates,
+    MonitoringComponentConfig,
+    MonitoringConfig,
     NetworkConfig,
     NetworkPolicy,
     NetworkPolicyConfig,
     NodeConfig,
+    NodeConfigDefaults,
+    NodeKubeletConfig,
     NodeManagement,
+    NodeNetworkConfig,
     NodePool,
     NodePoolAutoscaling,
+    NodePoolDefaults,
     NodeTaint,
+    NotificationConfig,
     Operation,
     OperationProgress,
     PrivateClusterConfig,
@@ -83,7 +103,9 @@ from .cluster_service import (
     ResourceUsageExportConfig,
     RollbackNodePoolUpgradeRequest,
     SandboxConfig,
+    SecurityBulletinEvent,
     ServerConfig,
+    ServiceExternalIPsConfig,
     SetAddonsConfigRequest,
     SetLabelsRequest,
     SetLegacyAbacRequest,
@@ -104,17 +126,25 @@ from .cluster_service import (
     UpdateClusterRequest,
     UpdateMasterRequest,
     UpdateNodePoolRequest,
+    UpgradeAvailableEvent,
+    UpgradeEvent,
     UsableSubnetwork,
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
+    VirtualNIC,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
+    DatapathProvider,
+    PrivateIPv6GoogleAccess,
+    UpgradeResourceType,
 )
 
 __all__ = (
     "AcceleratorConfig",
     "AddonsConfig",
+    "AdvancedMachineFeatures",
     "AuthenticatorGroupsConfig",
+    "Autopilot",
     "AutoprovisioningNodePoolDefaults",
     "AutoUpgradeOptions",
     "BinaryAuthorization",
@@ -125,6 +155,7 @@ __all__ = (
     "ClusterAutoscaling",
     "ClusterUpdate",
     "CompleteIPRotationRequest",
+    "ConfidentialNodes",
     "ConfigConnectorConfig",
     "CreateClusterRequest",
     "CreateNodePoolRequest",
@@ -134,6 +165,10 @@ __all__ = (
     "DeleteClusterRequest",
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
+    "DNSConfig",
+    "GcePersistentDiskCsiDriverConfig",
+    "GcfsConfig",
+    "GcpFilestoreCsiDriverConfig",
     "GetClusterRequest",
     "GetJSONWebKeysRequest",
     "GetJSONWebKeysResponse",
@@ -144,11 +179,13 @@ __all__ = (
     "GetServerConfigRequest",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
+    "ILBSubsettingConfig",
     "IntraNodeVisibilityConfig",
     "IPAllocationPolicy",
     "Jwk",
     "KubernetesDashboard",
     "LegacyAbac",
+    "LinuxNodeConfig",
     "ListClustersRequest",
     "ListClustersResponse",
     "ListNodePoolsRequest",
@@ -157,19 +194,30 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LoggingComponentConfig",
+    "LoggingConfig",
+    "MaintenanceExclusionOptions",
     "MaintenancePolicy",
     "MaintenanceWindow",
     "MasterAuth",
     "MasterAuthorizedNetworksConfig",
     "MaxPodsConstraint",
+    "MeshCertificates",
+    "MonitoringComponentConfig",
+    "MonitoringConfig",
     "NetworkConfig",
     "NetworkPolicy",
     "NetworkPolicyConfig",
     "NodeConfig",
+    "NodeConfigDefaults",
+    "NodeKubeletConfig",
     "NodeManagement",
+    "NodeNetworkConfig",
     "NodePool",
     "NodePoolAutoscaling",
+    "NodePoolDefaults",
     "NodeTaint",
+    "NotificationConfig",
     "Operation",
     "OperationProgress",
     "PrivateClusterConfig",
@@ -181,7 +229,9 @@ __all__ = (
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
     "SandboxConfig",
+    "SecurityBulletinEvent",
     "ServerConfig",
+    "ServiceExternalIPsConfig",
     "SetAddonsConfigRequest",
     "SetLabelsRequest",
     "SetLegacyAbacRequest",
@@ -202,9 +252,15 @@ __all__ = (
     "UpdateClusterRequest",
     "UpdateMasterRequest",
     "UpdateNodePoolRequest",
+    "UpgradeAvailableEvent",
+    "UpgradeEvent",
     "UsableSubnetwork",
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
+    "VirtualNIC",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
+    "DatapathProvider",
+    "PrivateIPv6GoogleAccess",
+    "UpgradeResourceType",
 )
